#include <chronoptics/tof/kea_camera.hpp>
#include <iostream>

namespace tof = chronoptics::tof;

int main() {
  /* Serial number of the camera to connect to. If this is empty, the
     first camera that is found will be connected to */
  const char* serial = "2020004";

  /* Config file to use. If the config file can't be found then a
     default one will be used */
  const char* configFile = "camera_config.bin";

  tof::CameraConfig config(configFile);

  /* Initialise a KeaCamera with all of the filters disabled, and use
     the given configuration */
  tof::KeaCamera cam(tof::ProcessingConfig{}, serial);
  cam.set_camera_config(config);

  /* Show all of the details for the given streams */
  auto streams = cam.get_stream_list();

  int n = 0;
  for (const auto& stream : streams) {
    std::cout << "List # " << n++ << std::endl;
    std::cout << "type: " << tof::frame_type_to_string(stream.frame_type())
              << std::endl;
    std::cout << "Frame id: " << stream.frame_id() << std::endl;
    std::cout << "frequency: " << stream.modulation_frequency() << std::endl;
    std::cout << "int_times: " << stream.integration_time() << std::endl;
    std::cout << "process: " << stream.process() << std::endl;
    std::cout << std::endl;
  }
}
