# For research purposes you might want to capture averaged data from a static scene.
# If you capture raw data, you'll have to store all these raw frames to disk and reprocess them every time.
# This is not necessary, starting from the 3.1 release of the tof library you can store complex data and reprocess it easily.
# This will be shown in this example

import chronoptics.tof as tof
import time


def capture_complex_averaged_data(
    file_name: str, average_n_frames: int, serial: str = ""
):
    config = tof.ProcessingConfig()

    # Disable calibration, such that it can be applied normally for reprocessing
    config.setCalibrationEnabled(False)

    cam = tof.KeaCamera(config, serial)
    writer = tof.createCsfWriterCamera(file_name, cam)

    tof.selectStreams(cam, [tof.FrameType.REAL, tof.FrameType.IMAGINARY])
    cam.start()

    print("Dropping frames for 2 seconds")

    # Wait for illumination to be warmed up
    time.sleep(2)

    config.setAverageEnabled(True)
    config.setAverageNframes(average_n_frames)

    cam.setProcessConfig(config)

    print("Averaging frames together")

    # Wait for data to be averaged, depending on the number of averages this might take a long time.
    # If it takes over 30 seconds, the cam.getFrames() function will throw
    while not cam.hasFrames():
        time.sleep(0.1)

    frames = cam.getFrames()

    for frame in frames:
        writer.writeFrame(frame)

    print("Capture finished")


def process_complex_averaged_data(file_name: str):
    config = tof.ProcessingConfig()

    # Adjust the processing config to your liking

    cam = tof.CsfCamera(config, file_name)
    tof.selectStreams(cam, [tof.FrameType.Z])
    cam.start()

    frames = cam.getFrames()

    # Do something with the averaged frames


file_name = "complex.csf"
capture_complex_averaged_data(file_name, 100)
process_complex_averaged_data(file_name)
